@@ -17,14 +17,6 @@ babi_nli = Classification("premise", "hypothesis", "label",
     config_name=set(get_dataset_config_names("metaeval/babi_nli"))-{"agents-motivations"}
 ) # agents-motivations task is not as clear-cut as the others
 
-def ling_nli_postprocess(ds):
-    return ds.cast_column('labels', ClassLabel(
-    names=['entailment','neutral','contradiction']))
-
-ling_nli = Classification("premise_original","hypothesis_original","label",
-    dataset_name="metaeval/lingnli", post_process=ling_nli_postprocess
-)
-
 
 sick__label         = Classification('sentence_A','sentence_B','label')
 sick__relatedness   = Classification('sentence_A','sentence_B','relatedness_score')
@@ -124,7 +116,7 @@ gen_debiased_nli__mnli_seq_z = Classification("premise","hypothesis","label",
 add_one_rte = Classification("premise","hypothesis","label",
     dataset_name="pietrolesci/add_one_rte",splits=["train","dev","test"])
 
-def imppres_post_process(ds,prefix=''):
+def _imppres_post_process(ds,prefix=''):
     # imppres entailment definition is either purely semantic or purely pragmatic
     # because of that, we assign differentiate the labels from anli/mnli notation
     return ds.cast_column('labels', ClassLabel(
@@ -132,15 +124,15 @@ def imppres_post_process(ds,prefix=''):
 
 imppres__presupposition = imppres__prag = Classification("premise","hypothesis","gold_label",
     dataset_name="metaeval/imppres", config_name=imppres_presupposition,
-    post_process=imppres_post_process)
+    post_process=_imppres_post_process)
 
 imppres__prag = Classification("premise","hypothesis","gold_label_prag",
     dataset_name="metaeval/imppres", config_name=imppres_implicature,
-    post_process=lambda x: imppres_post_process(x,'_prag'))
+    post_process=lambda x: _imppres_post_process(x,'_prag'))
 
 imppres__log = Classification("premise","hypothesis","gold_label_log",
     dataset_name="metaeval/imppres", config_name=imppres_implicature,
-    post_process=lambda x: imppres_post_process(x,'_log'))
+    post_process=lambda x: _imppres_post_process(x,'_log'))
 
 
 glue__diagnostics = Classification("premise","hypothesis","label",
@@ -279,6 +271,10 @@ balanced_copa = MultipleChoice('premise',['choice1','choice2'],'label',
     dataset_name="pkavumba/balanced-copa"
 )
 
+e_care = MultipleChoice('premise',['choice1','choice2'],'label',
+    dataset_name="12ml/e-CARE"
+)
+
 art = MultipleChoice(cat(['hypothesis_1','hypothesis_2']),
     ['observation_1','observation_2'],
     labels=lambda x:x['label']-1,
@@ -308,13 +304,13 @@ definite_pronoun_resolution = MultipleChoice(
 
 swag=MultipleChoice(cat(["sent1","sent2"]),regen("ending[0-3]"),"label")
 
-def split_choices(s):
+def _split_choices(s):
     import re
     return [x.rstrip(', ') for x in re.split(r'[a-e] \) (.*?)',s) if x.strip(', ')]
 
 math_qa = MultipleChoice(
     'Problem', 
-    choices_list = lambda x: split_choices(x['options']),
+    choices_list = lambda x: _split_choices(x['options']),
     labels = lambda x:'abcde'.index(x['correct'])   
 )
 
@@ -464,16 +460,15 @@ banking77 = Classification(sentence1="text", labels="label", splits=["train", No
 hate_speech_offensive = Classification(sentence1="tweet", labels="class", splits=["train", None, None])
 
 yahoo_answers_topics = Classification(
-    "question_title","answer",
-    splits=["train", None, "test"], config_name=["yahoo_answers_topics"]) 
+    "question_title","question_content",labels="topic")
 
 stackoverflow_questions=Classification("title","body",labels="label",
     dataset_name="pacovaldez/stackoverflow-questions")
 
-#hyperpartisan_news_detection___byarticle = Classification(sentence1="text", labels="hyperpartisan", splits=["train", None, None])
-#hyperpartisan_news_detection___bypublisher = Classification(sentence1="text", labels="hyperpartisan", splits=["train","validation", None])
-
+#hyperpartisan_news_detection___byarticle = Classification(sentence1="text", labels="hyperpartisan", splits=["train", None, None]) # files too heavy
+#hyperpartisan_news_detection___bypublisher = Classification(sentence1="text", labels="hyperpartisan", splits=["train","validation", None]) # files too heavy
 hyperpartisan_news = Classification("text",labels="label",dataset_name="zapsdcn/hyperpartisan_news")
+
 scierc = Classification("text",labels="label",dataset_name="zapsdcn/sciie")
 citation_intent = Classification("text",labels="label",dataset_name="zapsdcn/citation_intent")
 
@@ -497,7 +492,6 @@ relbert_lexical_relation_classification = Classification(sentence1="head", sente
 
 metaeval_linguisticprobing = Classification("sentence", labels="label", dataset_name="metaeval/linguisticprobing", 
     config_name=['subj_number',
-                'word_content',
                 'obj_number',
                 'past_present',
                 'sentence_length',
@@ -505,7 +499,7 @@ metaeval_linguisticprobing = Classification("sentence", labels="label", dataset_
                 'tree_depth',
                 'coordination_inversion',
                 'odd_man_out',
-                'bigram_shift']
+                'bigram_shift']#+['word_content'] #too many labels 
 )
 
 metaeval_crowdflower = Classification("text", labels="label",
@@ -586,13 +580,14 @@ circa = Classification(
     sentence2="answer-Y",
     labels="goldstandard2")
 
-code_x_glue_cc_defect_detection = Classification("func", labels="target")
+#code_x_glue_cc_defect_detection = Classification("func", labels="target")
 
 #code_x_glue_cc_clone_detection_big_clone_bench = Classification("func1", "func2", "label") # in bigbench + too heavy (100g)
 
-code_x_glue_cc_code_refinement = MultipleChoice(
-    constant(""), choices=["buggy","fixed"], labels=constant(0),
-    config_name="medium")
+#code_x_glue_cc_code_refinement = MultipleChoice(
+#    constant(""), choices=["buggy","fixed"], labels=constant(0),
+#    config_name="medium")
+
 effective_feedback_student_writing = Classification("discourse_text", labels="discourse_effectiveness",dataset_name="YaHi/EffectiveFeedbackStudentWriting")
 
 promptSentiment = Classification("text",labels="label",dataset_name="Ericwang/promptSentiment")
@@ -641,6 +636,56 @@ medmcqa = MultipleChoice("question", choices=regen('op[a-d]'),labels='cop')
 aqua_rat___tokenized = MultipleChoice("question",choices_list="options",
     labels=lambda x:"ABCDE".index(x['correct']))
 
+dynasent_disagreement    = Classification("text", labels="binary_disagreement", dataset_name="RuyuanWan/Dynasent_Disagreement")
+politeness_disagreement  = Classification("text", labels="binary_disagreement", dataset_name="RuyuanWan/Politeness_Disagreement")
+sbic_disagreement        = Classification("text", labels="binary_disagreement", dataset_name="RuyuanWan/SBIC_Disagreement")
+schem_disagreement       = Classification("text", labels="binary_disagreement", dataset_name="RuyuanWan/SChem_Disagreement")
+dilemmas_disagreement    = Classification("text", labels="binary_disagreement", dataset_name="RuyuanWan/Dilemmas_Disagreement")
 
-###END
-################### END OF SUPPORT ######################
+logiqa = MultipleChoice(
+    cat(["context","query"]),
+    choices_list = 'options',
+    labels = "correct_option",
+    dataset_name="lucasmccabe/logiqa"
+)
+
+proto_qa = MultipleChoice(
+    "question",
+    choices_list=lambda x:x['answer-clusters']['answers'],
+    labels=lambda x: x['answer-clusters']['count'].index(max(x['answer-clusters']['count'])),
+    config_name='proto_qa'
+)
+
+wiki_qa = Classification("question","answer","label")
+
+cycic_classification = Classification("question",labels="correct_answer",
+    dataset_name = "metaeval/cycic_classification")
+cycic_mc = MultipleChoice("question", choices=regen('answer\_option[0-4]'), labels="correct_answer",
+    dataset_name = "metaeval/cycic_multiplechoice")
+
+
+def _preprocess_chatgpt_detection(ex):
+    import random
+    label=random.random()<0.5
+    ex['label']=label
+    ex['answer']=[ex['human_answers'],ex['chatgpt_answers']][label]
+    return ex
+    
+chatgpt_detection = Classification("question","answer","label",
+    dataset_name = 'Hello-SimpleAI/HC3', config_name="all",
+    pre_process=lambda dataset:dataset.map(_preprocess_chatgpt_detection)
+)
+
+sts_companion = Classification("sentence1","sentence2","label",
+    dataset_name="metaeval/sts-companion"
+)
+
+commonsense_qa_2 = Classification("question",labels="answer",
+dataset_name="metaeval/commonsense_qa_2.0")
+
+
+ling_nli = Classification("premise","hypothesis","label",dataset_name="metaeval/lingnli")
+
+monotonicity_entailment = Classification("sentence1", "sentence2", "gold_label",    
+    dataset_name="metaeval/monotonicity-entailment"
+)
\ No newline at end of file
